package ai.think360.algo360pfm

import `in`.thinkanalytics.algo360SDK.Algo360_SDK_Init
import `in`.thinkanalytics.algo360SDK.ExtraHelperFunctions
import `in`.thinkanalytics.algo360SDK.Helpers.HelperClass

import ai.think360.algo360pfm.databinding.ActivityPermissionBinding
import android.content.pm.PackageManager
import android.graphics.Color
import android.os.Bundle
import android.text.method.LinkMovementMethod
import android.util.Log
import android.widget.Button
import android.widget.TextView
import androidx.appcompat.app.AppCompatActivity
import androidx.core.app.ActivityCompat
import androidx.core.content.ContextCompat
import com.google.android.material.snackbar.Snackbar

class PermissionActivity : AppCompatActivity() {

    lateinit var binding: ActivityPermissionBinding
    var userId: String? = null
    var env: String? = null
    var clientId: String? = null
    var clientSecret: String? = null

    override fun onCreate(savedInstanceState: Bundle?) {

        userId = intent.getStringExtra("userId")
        env = intent.getStringExtra("env")
        clientId = intent.getStringExtra("clientId")
        clientSecret = intent.getStringExtra("clientSecret")

        Log.d("PASSED_VALUES", "onCreate: Values: $userId, $env, $clientId, $clientSecret")

        if (HelperClass.getFromSettings(applicationContext, "THEME") == "LIGHT") {
            setTheme(R.style.Theme_AppCompat_Light_NoActionBar)
        } else {
            setTheme(R.style.Theme_AppCompat_DayNight_NoActionBar)
        }

        super.onCreate(savedInstanceState)
        binding = ActivityPermissionBinding.inflate(layoutInflater)
        val view = binding.root
        setContentView(view)

        val allowButton = findViewById<Button>(R.id.buttonAllow)

        allowButton.setOnClickListener {
            invokeAlgo360SDK(
                userId = userId!!,
                env = env!!,
                clientId = clientId!!,
                clientSecret = clientSecret!!
            )
        }

        setupHyperlink()

    }


    private fun setupHyperlink() {
        val termsAndConditionsLinkText = findViewById<TextView>(R.id.textViewTermsAndConditions)
        val privacyPolicyLinkText = findViewById<TextView>(R.id.textViewPrivacyPolicy)
        termsAndConditionsLinkText.movementMethod = LinkMovementMethod.getInstance()
        privacyPolicyLinkText.movementMethod = LinkMovementMethod.getInstance()
        termsAndConditionsLinkText.setLinkTextColor(Color.BLUE)
        privacyPolicyLinkText.setLinkTextColor(Color.BLUE)
    }

    private fun invokeAlgo360SDK(
        userId: String,
        env: String,
        clientId: String,
        clientSecret: String
    ) {
        val sdkEnv = if (env == "UAT") {
            Algo360_SDK_Init.TESTING_ENV
        } else {
            Algo360_SDK_Init.PRODUCTION_ENV
        }
        if (ContextCompat.checkSelfPermission(
                this,
                android.Manifest.permission.READ_SMS
            ) !=
            PackageManager.PERMISSION_GRANTED
        ) {
            ActivityCompat.requestPermissions(
                this,
                arrayOf(android.Manifest.permission.READ_SMS), 1
            )
        } else {
            ExtraHelperFunctions.putRefUserId(applicationContext, userId)
            ExtraHelperFunctions.putClientId(applicationContext, clientId)
            ExtraHelperFunctions.putClientSecret(applicationContext, clientSecret)
            Algo360_SDK_Init.startAlgo360(
                applicationContext,
                sdkEnv,
                Algo360_SDK_Init.ENABLE_PRINT
            )
            finish()
        }
    }

    override fun onRequestPermissionsResult(
        requestCode: Int, permissions: Array<String>,
        grantResults: IntArray
    ) {
        super.onRequestPermissionsResult(requestCode, permissions, grantResults)
        when (requestCode) {
            1 -> {
                if (grantResults.isNotEmpty() && grantResults[0] ==
                    PackageManager.PERMISSION_GRANTED
                ) {
                    if ((ContextCompat.checkSelfPermission(
                            this,
                            android.Manifest.permission.READ_SMS
                        ) ==
                                PackageManager.PERMISSION_GRANTED)
                    ) {
                        val snack = Snackbar.make(
                            findViewById(R.id.constraintLayoutPermission),
                            "Permission Granted",
                            Snackbar.LENGTH_LONG
                        )
                        snack.show()
                        val sdkEnv = if (env == "UAT") {
                            Algo360_SDK_Init.TESTING_ENV
                        } else {
                            Algo360_SDK_Init.PRODUCTION_ENV
                        }
                        ExtraHelperFunctions.putRefUserId(applicationContext, userId)
                        ExtraHelperFunctions.putClientId(applicationContext, clientId)
                        ExtraHelperFunctions.putClientSecret(applicationContext, clientSecret)
                        Algo360_SDK_Init.startAlgo360(
                            applicationContext,
                            sdkEnv,
                            Algo360_SDK_Init.ENABLE_PRINT
                        )
                        finish()
                    }
                } else {
                    val snack = Snackbar.make(
                        findViewById(R.id.constraintLayoutPermission),
                        "Permission Denied",
                        Snackbar.LENGTH_LONG
                    )
                    snack.show()
                    finish()
                }
                return
            }
        }
    }
}