package ai.think360.algo360pfm.services

import `in`.thinkanalytics.algo360SDK.Algo360_SDK_Init
import `in`.thinkanalytics.algo360SDK.ExtraHelperFunctions
import ai.think360.algo360pfm.PermissionActivity
import android.Manifest
import android.app.Activity
import android.content.Context
import android.content.DialogInterface
import android.content.Intent
import android.content.pm.PackageManager
import android.util.Log
import androidx.appcompat.app.AlertDialog
import androidx.core.app.ActivityCompat

class PermissionService(
    context: Context,
    env: String,
    userId: String,
    clientId: String,
    clientSecret: String
) {
    var mcontext: Context = context
    var listener: (() -> Unit)? = null
    var env: String? = env
    var userId: String? = userId
    var clientId: String? = clientId
    var clientSecret: String? = clientSecret

    private var PERMISSIONS = arrayOf(
        Manifest.permission.READ_SMS,
    )

    fun getAllPermission() {
        val isAllPermission = hasPermissions(mcontext)
        Log.d("DATA", "isAllPermission = $isAllPermission , ${PERMISSIONS.size}")
        if (!isAllPermission) {
//            val intent = Intent(mcontext, PermissionActivity::class.java)
//
//            mcontext.startActivity(intent)
            ActivityCompat.requestPermissions(
                mcontext as Activity, PERMISSIONS,
                1001
            )

            val sdkEnv = if (env == "UAT") {
                Algo360_SDK_Init.TESTING_ENV
            } else {
                Algo360_SDK_Init.PRODUCTION_ENV
            }

            ExtraHelperFunctions.putRefUserId(mcontext, userId)
            ExtraHelperFunctions.putClientId(mcontext, clientId)
            ExtraHelperFunctions.putClientSecret(mcontext, clientSecret)
            Algo360_SDK_Init.startAlgo360(
                mcontext,
                sdkEnv,
                Algo360_SDK_Init.ENABLE_PRINT
            )
            showDialogOK("Please wait while things are being processed...") { _, _ ->
                (mcontext as Activity).finish()

            }

        }
    }

    fun hasPermissions(context: Context): Boolean = PERMISSIONS.all {
        ActivityCompat.checkSelfPermission(context, it) == PackageManager.PERMISSION_GRANTED
    }

    fun handlePermissionResult(permissions: Array<String>, grantResults: IntArray) {
        var allPermissionSucces = true
        var isStillRationalAvailable = true
        for ((index, per) in permissions.withIndex()) {
            if (allPermissionSucces) allPermissionSucces =
                grantResults[index] == PackageManager.PERMISSION_GRANTED
            if (isStillRationalAvailable)
                isStillRationalAvailable =
                    ActivityCompat.shouldShowRequestPermissionRationale(
                        mcontext as Activity,
                        per
                    ) || grantResults[index] == PackageManager.PERMISSION_GRANTED
        }

        Log.d("DATA", "allPermissionSuccess = $allPermissionSucces")
        Log.d("DATA", "isStillRationalAvailable = $isStillRationalAvailable")
        if (!allPermissionSucces) {
            showDialogOK(
                "This permission is necessary in order to view finance dashboard."
            ) { _, which ->
                when (which) {
                    DialogInterface.BUTTON_POSITIVE -> getAllPermission(
                    )
                }
            }
        } else {
            Log.d("FINAL", "allPermissionSucces else = $allPermissionSucces")
            listener?.invoke()
        }
    }

    fun showDialogOK(message: String, okListener: DialogInterface.OnClickListener) {
        AlertDialog.Builder(mcontext)
            .setMessage(message)
            .setPositiveButton("OK", okListener)
            .create()
            .show()
    }
}