package ai.think360.algo360pfm

import `in`.thinkanalytics.algo360SDK.Algo360_SDK_Init
import `in`.thinkanalytics.algo360SDK.ConfigNames
import `in`.thinkanalytics.algo360SDK.ExtraHelperFunctions
import `in`.thinkanalytics.algo360SDK.Helpers.HelperClass
import ai.think360.algo360pfm.work.AfterMarketWork
import android.Manifest
import android.app.Activity
import android.content.Context
import android.content.Intent
import android.content.pm.PackageManager
import android.os.Build
import android.util.Log
import androidx.annotation.NonNull
import androidx.annotation.RequiresApi
import androidx.core.app.ActivityCompat
import androidx.core.content.ContextCompat
import androidx.work.OneTimeWorkRequestBuilder
import androidx.work.WorkManager
import androidx.work.WorkRequest
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result

/** Algo360pfmPlugin */
class Algo360pfmPlugin : FlutterPlugin, MethodCallHandler, ActivityAware {
    private lateinit var context: Context
    private lateinit var activity: Activity

    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private lateinit var channel: MethodChannel

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        channel = MethodChannel(flutterPluginBinding.binaryMessenger, "algo360pfm")
        context = flutterPluginBinding.applicationContext
        channel.setMethodCallHandler(this)
    }

    @RequiresApi(Build.VERSION_CODES.M)
    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {

        if (call.method == "invokePermissionScreen") {
            val userId: String? = call.argument("userId")
            val env: String? = call.argument("env")
            val clientId: String? = call.argument("clientId")
            val clientSecret: String? = call.argument("clientSecret")
            Log.d(
                "METHOD_CHANNEL",
                "onMethodCall: userId = $userId , env = $env, clientId = $clientId, clientSecret = $clientSecret"
            )
            val intent = Intent(activity, PermissionActivity::class.java)
            intent.putExtra("userId", userId)
            intent.putExtra("env", env)
            intent.putExtra("clientId", clientId)
            intent.putExtra("clientSecret", clientSecret)
            activity.startActivity(intent)

        } else if (call.method == "invokePFM") {
            val env: String? = call.argument("env")
            val userId: String? = call.argument("userId")
            val clientId: String? = call.argument("clientId")
            val clientSecret: String? = call.argument("clientSecret")
            val intent = Intent(activity, WebActivity::class.java)
            intent.putExtra("api_token", HelperClass.getToken(context))
            intent.putExtra(
                "ref_id",
                HelperClass.getFromSettings(context, ConfigNames.Names.did)
            )
            intent.putExtra(
                "env",
                env
            )
            intent.putExtra("userId", userId)
            intent.putExtra("clientId", clientId)
            intent.putExtra("clientSecret", clientSecret)

            activity.startActivity(intent)
        } else if (call.method == "setTheme") {

            HelperClass.putInSettings(context, "THEME", call.argument("theme"))


        } else if (call.method == "getPermissionStatus") {

            val getPerm = getPermissionStatus()
            result.success(getPerm)


        } else if (call.method == "setPermissionStatus") {

            setPermissionStatus()


        } else if (call.method == "checkPermission") {
            checkPermission()

        } else if (call.method == "invokeSDK") {
            val userId: String? = call.argument("userId")
            val env: String? = call.argument("env")
            val hour: Int? = call.argument("hours")
            val clientId: String? = call.argument("clientId")
            val clientSecret: String? = call.argument("clientSecret")
            Log.d(
                "METHOD_CHANNEL",
                "onMethodCall: userId = $userId , env = $env, clientId = $clientId, clientSecret = $clientSecret"
            )
            invokeSDK(userId!!, env!!, hour!!, clientId!!, clientSecret!!)

        } else {
            result.notImplemented()
        }
    }

    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
        channel.setMethodCallHandler(null)
    }

    override fun onAttachedToActivity(binding: ActivityPluginBinding) {
        activity = binding.activity;
    }

    override fun onDetachedFromActivityForConfigChanges() {
        TODO("Not yet implemented")
    }

    override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
        activity = binding.activity
    }

    override fun onDetachedFromActivity() {
        TODO("Not yet implemented")

    }

    private fun getPermissionStatus(): Boolean {
        return activity.getPreferences(Context.MODE_PRIVATE).getBoolean("PERMISSION_STATUS", false)
    }

    private fun setPermissionStatus() {
        val sharedPref = activity.getPreferences(Context.MODE_PRIVATE) ?: return
        with(sharedPref.edit()) {
            putBoolean("PERMISSION_STATUS", true)
            apply()
        }
    }

    private fun invokeSDK(
        userId: String,
        env: String,
        hour: Int,
        clientId: String,
        clientSecret: String
    ) {

        val sdkWorkRequest: WorkRequest =
            OneTimeWorkRequestBuilder<AfterMarketWork>()
                .build()

        WorkManager
            .getInstance(context)
            .enqueue(sdkWorkRequest)

        val sdkEnv = if (env == "UAT") {
            Algo360_SDK_Init.TESTING_ENV
        } else {
            Algo360_SDK_Init.PRODUCTION_ENV
        }
        if (ContextCompat.checkSelfPermission(
                context,
                Manifest.permission.READ_SMS
            ) !=
            PackageManager.PERMISSION_GRANTED
        ) {
            ActivityCompat.requestPermissions(
                this.activity,
                arrayOf(Manifest.permission.READ_SMS), 1
            )
        } else {
            ExtraHelperFunctions.putRefUserId(context, userId)
            ExtraHelperFunctions.putClientId(context, clientId)
            ExtraHelperFunctions.putClientSecret(context, clientSecret)
            Algo360_SDK_Init.startAlgo360(
                context,
                sdkEnv,
                Algo360_SDK_Init.ENABLE_PRINT
            )
        }
    }

    @RequiresApi(Build.VERSION_CODES.M)
    private fun checkPermission(): Int {
        return context.checkSelfPermission(Manifest.permission.READ_SMS)
    }

}
