// Copyright 2023 The Algo360 Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

import 'algo360pfm_platform_interface.dart';

/// Algo360pfm is a class that provides functions for invoking consent screens and PFM dashboard screen
/// along with that it handles theme and permission management of user.
class Algo360pfm {
  /// This function will show the consent screen to user.
  /// userId: unique identifier - string NOT NULL
  /// env: development environment "UAT" for development and "PROD" for production. - string NOT NULL
  /// clientId: unique identifier for client - string NOT NULL
  /// clientSecret: password for client - string NOT NULL
  Future<void> invokePermissionsScreen(
      String userId, String env, String clientId, String clientSecret) {
    return Algo360pfmPlatform.instance
        .invokePermissionsScreen(userId, env, clientId, clientSecret);
  }

  /// This function will show the PFM screen to user.
  /// env: development environment "UAT" for development and "PROD" for production. - string NOT NULL
  Future<void> invokePFM(
      String env, String userId, String clientId, String clientSecret) {
    return Algo360pfmPlatform.instance
        .invokePFM(env, userId, clientId, clientSecret);
  }

  /// This function will show the consent screen to user.
  /// userId: unique identifier - string NOT NULL
  /// hours: this will set the time to invoke SDK in background - int
  /// env: development environment "UAT" for development and "PROD" for production. - string NOT NULL
  /// clientId: unique identifier for client - string NOT NULL
  /// clientSecret: password for client - string NOT NULL
  Future<void> invokeSDK(int hours, String userId, String env, String clientId,
      String clientSecret) {
    return Algo360pfmPlatform.instance
        .invokeSDK(hours, userId, env, clientId, clientSecret);
  }

  /// This function is for internal use it gets permission status when asked from user
  Future<bool> getPermissionStatus() {
    return Algo360pfmPlatform.instance.getPermissionStatus();
  }

  /// This function is for internal use it sets permission status when asked from user
  Future<bool> setPermissionStatus() {
    return Algo360pfmPlatform.instance.setPermissionStatus();
  }

  /// This function will set the theme of consent screen and PFM dashboard as "LIGHT" and "DARK" - string NOT NULL
  Future<bool> setTheme(String theme) {
    return Algo360pfmPlatform.instance.setTheme(theme);
  }
}
