// Copyright 2023 The Algo360 Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';

import 'algo360pfm_platform_interface.dart';

/// An implementation of [Algo360pfmPlatform] that uses method channels.
class MethodChannelAlgo360pfm extends Algo360pfmPlatform {
  /// The method channel used to interact with the native platform.
  @visibleForTesting
  final methodChannel = const MethodChannel('algo360pfm');

  @override

  ///This method implements the invokePermissionScreen and communicated with native side passes values and maintains proper checks
  Future<void> invokePermissionsScreen(
      userId, env, clientId, clientSecret) async {
    /// Check if the permission screen is already shown to user if not then show consent screen and ask for permission otherwise skip
    var isPermissionAsked =
        await methodChannel.invokeMethod<bool>("getPermissionStatus");
    if (isPermissionAsked != null) {
      if (isPermissionAsked) {
      } else {
        methodChannel.invokeMethod<String>('invokePermissionScreen', {
          "userId": userId,
          "env": env,
          "clientId": clientId,
          "clientSecret": clientSecret
        });

        /// Once consent screen is showed set permission to asked.
        methodChannel.invokeMethod<String>('setPermissionStatus');
      }
    }
  }

  @override

  ///This method implements the invokeSDK and communicated with native side passes values and maintains proper checks
  Future<void> invokeSDK(hours, userId, env, clientId, clientSecret) async {
    methodChannel.invokeMethod<String>('invokeSDK', {
      "hours": hours,
      "userId": userId,
      "env": env,
      "clientId": clientId,
      "clientSecret": clientSecret
    });
  }

  @override

  ///This method implements the invokePFM and communicated with native side passes values and maintains proper checks
  Future<void> invokePFM(env, userId, clientId, clientSecret) async {
    methodChannel.invokeMethod<String>('invokePFM', {
      "env": env,
      "userId": userId,
      "clientId": clientId,
      "clientSecret": clientSecret
    });
  }

  @override

  ///This method implements the setTheme and communicated with native side passes values and maintains proper checks
  Future<bool> setTheme(theme) async {
    methodChannel.invokeMethod<String>('setTheme', {"theme": theme});
    return true;
  }
}
