// Copyright 2023 The Algo360 Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

import 'package:plugin_platform_interface/plugin_platform_interface.dart';

import 'algo360pfm_method_channel.dart';

abstract class Algo360pfmPlatform extends PlatformInterface {
  /// Constructs a Algo360pfmPlatform.
  Algo360pfmPlatform() : super(token: _token);

  static final Object _token = Object();

  /// instance of a method channel
  static Algo360pfmPlatform _instance = MethodChannelAlgo360pfm();

  /// The default instance of [Algo360pfmPlatform] to use.
  ///
  /// Defaults to [MethodChannelAlgo360pfm].
  static Algo360pfmPlatform get instance => _instance;

  /// Platform-specific implementations should set this with their own
  /// platform-specific class that extends [Algo360pfmPlatform] when
  /// they register themselves.
  static set instance(Algo360pfmPlatform instance) {
    PlatformInterface.verifyToken(instance, _token);
    _instance = instance;
  }

  Future<void> invokePermissionsScreen(userId, env, clientId, clientSecret) {
    throw UnimplementedError(
        'invokePermissionsScreen() has not been implemented.');
  }

  Future<void> invokePFM(env, userId, clientId, clientSecret) {
    throw UnimplementedError('invokePFM() has not been implemented.');
  }

  Future<void> invokeSDK(hours, userId, env, clientId, clientSecret) {
    throw UnimplementedError('invokePFM() has not been implemented.');
  }

  Future<bool> getPermissionStatus() {
    throw UnimplementedError('getPermissionStatus() has not been implemented.');
  }

  Future<bool> setPermissionStatus() {
    throw UnimplementedError('setPermissionStatus() has not been implemented.');
  }

  Future<bool> setTheme(theme) {
    throw UnimplementedError('setTheme() has not been implemented.');
  }
}
